==> pegasus-support-1.6.30-sources.jar: com/thebeastshop/support/vo/product/ProductLotteryShareVO.java <==
package com.thebeastshop.support.vo.product;

import java.io.Serializable;

/**
 * 抽奖分享实体
 *
 */
public class ProductLotteryShareVO implements Serializable {
	private ShareData shareData;
	private String showType;// 刮刮乐or弹窗
	private String dataPack;

	public String getDataPack() {
		return dataPack;
	}

	public void setDataPack(String dataPack) {
		this.dataPack = dataPack;
	}

	public ShareData getShareData() {
		return shareData;
	}

	public void setShareData(ShareData shareData) {
		this.shareData = shareData;
	}

	public String getShowType() {
		return showType;
	}

	public void setShowType(String showType) {
		this.showType = showType;
	}

	public static class ShareData implements Serializable {

		private String title;
		private String image;
		private String content;
		private String link;
		private String imageLink;
		private String type;

		public String getTitle() {
			return title;
		}

		public void setTitle(String title) {
			this.title = title;
		}

		public String getImage() {
			return image;
		}

		public void setImage(String image) {
			this.image = image;
		}

		public String getContent() {
			return content;
		}

		public void setContent(String content) {
			this.content = content;
		}

		public String getLink() {
			return link;
		}

		public void setLink(String link) {
			this.link = link;
		}

		public String getImageLink() {
			return imageLink;
		}

		public void setImageLink(String imageLink) {
			this.imageLink = imageLink;
		}

		public String getType() {
			return type;
		}

		public void setType(String type) {
			this.type = type;
		}

	}

	@Override
	public String toString() {
		return "ProductLotteryShareVO [shareData =" + shareData + ", showType =" + showType + ", dataPack =" + dataPack
				+ "]";
	}
}

==> pegasus-support-2.2.9-sources.jar: com/thebeastshop/support/vo/product/ProductLotteryShareVO.java <==
package com.thebeastshop.support.vo.product;

import java.io.Serializable;

/**
 * 抽奖分享实体
 *
 */
public class ProductLotteryShareVO implements Serializable {
	private ShareData shareData;
	private String showType;// 刮刮乐or弹窗
	private String dataPack;

	public String getDataPack() {
		return dataPack;
	}

	public void setDataPack(String dataPack) {
		this.dataPack = dataPack;
	}

	public ShareData getShareData() {
		return shareData;
	}

	public void setShareData(ShareData shareData) {
		this.shareData = shareData;
	}

	public String getShowType() {
		return showType;
	}

	public void setShowType(String showType) {
		this.showType = showType;
	}

	public static class ShareData implements Serializable {

		private String title;
		private String image;
		private String content;
		private String link;
		private String imageLink;
		private String prodImageLink;
        private String prodTitle;
		private String type;

		public String getTitle() {
			return title;
		}

		public void setTitle(String title) {
			this.title = title;
		}

		public String getImage() {
			return image;
		}

		public void setImage(String image) {
			this.image = image;
		}

		public String getContent() {
			return content;
		}

		public void setContent(String content) {
			this.content = content;
		}

		public String getLink() {
			return link;
		}

		public void setLink(String link) {
			this.link = link;
		}

		public String getImageLink() {
			return imageLink;
		}

		public void setImageLink(String imageLink) {
			this.imageLink = imageLink;
		}

		public String getProdImageLink() {
			return prodImageLink;
		}

		public void setProdImageLink(String prodImageLink) {
			this.prodImageLink = prodImageLink;
		}

        public String getProdTitle() {
            return prodTitle;
        }

        public void setProdTitle(String prodTitle) {
            this.prodTitle = prodTitle;
        }

        public String getType() {
			return type;
		}

		public void setType(String type) {
			this.type = type;
		}

	}

	@Override
	public String toString() {
		return "ProductLotteryShareVO [shareData =" + shareData + ", showType =" + showType + ", dataPack =" + dataPack
				+ "]";
	}
}
